==> igniteui-angular-charts-14.1.1.tgz: package/esm2015/lib/ForceIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ForceIndexIndicatorStrategy } from "./ForceIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let ForceIndexIndicator = /*@__PURE__*/ (() => {
    class ForceIndexIndicator extends StrategyBasedIndicator {
        constructor() {
            super();
        }
        get_to() {
            return 1;
        }
        get_uh() {
            return new ForceIndexIndicatorStrategy();
        }
        get uh() {
            return this.get_uh();
        }
        get_uu() {
            return ForceIndexIndicator.$;
        }
        get uu() {
            return this.get_uu();
        }
        get u2() {
            return typeGetValue(this.c(ForceIndexIndicator.u3));
        }
        set u2(a) {
            this.h(ForceIndexIndicator.u3, a);
        }
        un() {
            return this.u2;
        }
        uw(a) {
            this.u2 = a;
        }
    }
    ForceIndexIndicator.$t = markType(ForceIndexIndicator, 'ForceIndexIndicator', StrategyBasedIndicator.$);
    ForceIndexIndicator.u3 = StrategyBasedIndicator.uz(0, ForceIndexIndicator.$);
    return ForceIndexIndicator;
})();

==> igniteui-angular-charts-16.0.0.tgz: package/esm2015/lib/ForceIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ForceIndexIndicatorStrategy } from "./ForceIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let ForceIndexIndicator = /*@__PURE__*/ (() => {
    class ForceIndexIndicator extends StrategyBasedIndicator {
        constructor() {
            super();
        }
        get_ts() {
            return 1;
        }
        get_ul() {
            return new ForceIndexIndicatorStrategy();
        }
        get ul() {
            return this.get_ul();
        }
        get_uy() {
            return ForceIndexIndicator.$;
        }
        get uy() {
            return this.get_uy();
        }
        get u6() {
            return typeGetValue(this.c(ForceIndexIndicator.u7));
        }
        set u6(a) {
            this.h(ForceIndexIndicator.u7, a);
        }
        ur() {
            return this.u6;
        }
        u0(a) {
            this.u6 = a;
        }
    }
    ForceIndexIndicator.$t = markType(ForceIndexIndicator, 'ForceIndexIndicator', StrategyBasedIndicator.$);
    ForceIndexIndicator.u7 = StrategyBasedIndicator.u3(0, ForceIndexIndicator.$);
    return ForceIndexIndicator;
})();
